Contains the column descriptions and data for the datatable part of a GEO object
Objects from the Class
Objects of this class are returned by
getGEO; they are not normally constructed directly.
Contains the column descriptions and data for the datatable part of a GEO object
Objects of this class are returned by
getGEO; they are not normally constructed directly.