Skip to contents

This function extracts the genome build and species information for a GEO RNA-seq quantification.

Usage

getRNASeqQuantGenomeInfo(gse)

Arguments

gse

GEO accession number

Value

A character vector with the genome build and species information

Examples

if (FALSE) { # \dontrun{
getRNASeqQuantGenomeInfo("GSE164073")

} # }