This function extracts the filename from a GEO download URL. The filename is expected to be a query parameter called "file". If the query parameter is not found, the function returns NULL.
This function extracts the filename from a GEO download URL. The filename is expected to be a query parameter called "file". If the query parameter is not found, the function returns NULL.